$set 3 #Configmenu

$ #ConfigOptions
# Options de configuration
$ #FocusModel
# Mode de convergence
$ #WindowPlacement
# Disposition des fentres
$ #ImageDithering
# Lissage d'images
$ #OpaqueMove
# Dplacement opaque des fentres
$ #FullMax
# Maximization complte
$ #FocusNew
# Convergence de la nouvelle fentre
$ #FocusLast
# Convergence de la dernire fentre
$ #ClickToFocus
# Cliquer pour converger
$ #SloppyFocus
# Convergence souple
$ #AutoRaise
# Premier plan automatique
$ #SmartRows
# Disposition fute (Lignes)
$ #SmartCols
# Disposition fute (Colonnes)
$ #Cascade
# Disposition en cascade
$ #LeftRight
# De gauche  droite
$ #RightLeft
# De droite  gauche
$ #TopBottom
# De haut en bas
$ #BottomTop
# De bas en haut
$ #Tabs
# Utiliser les onglets
$ #Icons
# Utiliser les icones
$ #TabPlacement
# Emplacement des onglets
$ #TabRotateVertical
# Rotation verticale des onglets
$ #SemiSloppyFocus
# Focus semi-stupide
$ #MaxOverSlit
# Maximisez au dessus du Slit
$ #SloppyWindowGrouping
# Groupement des fentres stupide
$ #WorkspaceWarping
# Workspace Warping
